<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Module\CDev\Sale\View;

/**
 * Search
 */
 class Search extends \XLite\Module\QSL\CloudSearch\View\ItemsList\Model\Product\Admin\Search implements \XLite\Base\IDecorator
{
    /**
     * Register JS files
     *
     * @return array
     */
    public function getJSFiles()
    {
        $list = parent::getJSFiles();

        // TODO: Remove after JS-autoloading is added.
        $list[] = 'modules/CDev/Sale/sale_discount_types/js/script.js';

        return $list;
    }

    /**
     * Register CSS files
     *
     * @return array
     */
    public function getCSSFiles()
    {
        $list = parent::getCSSFiles();

        // TODO: Remove after CSS-autoloading is added.
        $list[] = 'modules/CDev/Sale/sale_discount_types/css/style.css';

        return $list;
    }
}
